
//--- input parameters
input int InpWPRPeriod   = 14; // Period
input int dist           = 20; // Distance

#include "..\Model\InputBase.mqh"

class CInputParam: public IInputBase {
   public:
                  CInputParam() {}
                 ~CInputParam() {}
     
     const int    GetPeriod()   const final {return iWprPeriod;}
     const double GetDistance() const       {return dDistance; }
     const color  GetBckColor() const       {return clrBck;    }
      
   protected:
           int    iWprPeriod;
           double dDistance;
           color  clrBck;   

};

class CInputManager: public CInputParam {
   public:
                  CInputManager(int minperiod, int defperiod): iMinPeriod(minperiod),
                                                               iDefPeriod(defperiod)
                  {}                                             
                  CInputManager() {
                     iMinPeriod = 3;
                     iDefPeriod = 14;
                  }
                 ~CInputManager() {}
           int   Initialize();
           bool   Update() {return GetData(); }
      
   protected:
           int   VerifyParam();
           bool   GetData();
   private:
      int iMinPeriod;
      int iDefPeriod;
}; 

int CInputManager::Initialize() {
   
   int iResult = VerifyParam();
   if (iResult == INIT_SUCCEEDED) GetData();
   
   return iResult;
}

bool CInputManager::GetData() {

  long tmp;
  bool res = SymbolInfoInteger(_Symbol, SYMBOL_BACKGROUND_COLOR, tmp);
  if (res) clrBck = (color)tmp;
  
  return res;
}

int CInputManager::VerifyParam() {

   int iResult = INIT_SUCCEEDED;
   
   if(InpWPRPeriod < iMinPeriod) {
      iWprPeriod = iDefPeriod;
      Print("Incorrect InpWPRPeriod value. Indicator will use value=", iWprPeriod);
   }
   else
      iWprPeriod = InpWPRPeriod;
      
   if (dist <= 0) {
      Print("Incorrect Distance value. Indicator will use value=", dist);
      iResult = INIT_PARAMETERS_INCORRECT;
      dDistance = 0;
   } else       
      dDistance = dist * _Point;
   
   return iResult;
}
